@@ -13,7 +13,7 @@ private import StoreFoundation
 
 extension AppStoreAction { // swiftlint:disable:this file_types_order
 	@MainActor
-	func app(withADAMID adamID: ADAMID, shouldCancel: @Sendable @escaping (String?, Bool) -> Bool) async throws {
+	func app(withADAMID adamID: ADAMID, shouldCancel: @escaping @Sendable (String?, Bool) -> Bool) async throws {
 		let purchase = SSPurchase(
 			buyParameters: """
 				productType=C&price=0&pg=default&appExtVrsId=0&pricingParameters=\
@@ -71,7 +71,7 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 	private var receiptHardLinkURL = URL?.none
 	private var alreadyResumed = false
 
-	init(for action: AppStoreAction, of adamID: ADAMID, shouldCancel: @Sendable @escaping (String?, Bool) -> Bool) {
+	init(for action: AppStoreAction, of adamID: ADAMID, shouldCancel: @escaping @Sendable (String?, Bool) -> Bool) {
 		self.action = action
 		self.adamID = adamID
 		self.shouldCancel = shouldCancel
@@ -164,9 +164,9 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 			)
 			do {
 				pkgHardLinkURL = try hardLinkURL(
-					to: try downloadFolderChildURLs.compactMap { url -> (url: URL, date: Date)? in
+					to: try downloadFolderChildURLs.compactMap { url in
 						guard url.pathExtension == "pkg" else {
-							return nil
+							return nil as (url: URL, date: Date)?
 						}
 
 						let resourceValues = try url.resourceValues(forKeys: [.contentModificationDateKey, .isRegularFileKey])
@@ -191,7 +191,7 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 		} catch {
 			MAS.printer.warning(
 				"Failed to read contents of download folder",
-				downloadFolderURL.path(percentEncoded: false).quoted,
+				downloadFolderURL.filePath.quoted,
 				"for",
 				snapshot.appNameAndVersion,
 				error: error,
@@ -238,6 +238,7 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 		MAS.printer.clearCurrentLine(of: .standardOutput)
 
 		do {
+			let appFolderURL: URL?
 			if let error = snapshot.error {
 				guard error is Ignorable else {
 					throw error
@@ -250,7 +251,7 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 					"progress cannot be displayed",
 					terminator: "",
 				)
-				try await install(appNameAndVersion: snapshot.appNameAndVersion)
+				appFolderURL = try await install(appNameAndVersion: snapshot.appNameAndVersion)
 				MAS.printer.clearCurrentLine(of: .standardOutput)
 			} else {
 				guard !snapshot.isFailed else {
@@ -263,9 +264,55 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 				guard !snapshot.isCancelled else {
 					throw MASError.error("Download cancelled for \(snapshot.appNameAndVersion)")
 				}
+
+				appFolderURL = snapshot.appFolderPath.map { .init(filePath: $0, directoryHint: .isDirectory) }
+			}
+
+			MAS.printer.notice(
+				[action.performed.capitalizingFirstCharacter, snapshot.appNameAndVersion]
+				+ (appFolderURL.map { ["in", $0.filePath] } ?? []), // swiftformat:disable:this indent
+			)
+
+			if let appFolderURL {
+				let fileManager = FileManager.default
+				if
+					try applicationsFolderURLs.contains(
+						where: { applicationsFolderURL in
+							var relationship = FileManager.URLRelationship.other
+							try unsafe fileManager.getRelationship(
+								&relationship,
+								ofDirectoryAt: applicationsFolderURL,
+								toItemAt: appFolderURL,
+							)
+							return relationship == .contains
+						},
+					)
+				{
+					let appFolderPath = appFolderURL.filePath
+					let installedApps = try await installedApps(withADAMID: snapshot.adamID).filter { $0.path != appFolderPath }
+					if !installedApps.isEmpty {
+						MAS.printer.warning(
+							"Multiple installations of ",
+							snapshot.name ?? "unknown app",
+							" exist in the applications folders\n\n",
+							action.performed.capitalizingFirstCharacter,
+							":\n",
+							appFolderPath,
+							"\n\nOthers:\n",
+							installedApps.map(\.path).sorted(using: .localizedStandard).joined(separator: "\n"),
+							separator: "",
+						)
+					}
+				} else {
+					MAS.printer.warning(
+						action.performed.capitalizingFirstCharacter,
+						snapshot.appNameAndVersion,
+						"outside of the applications folders, in",
+						appFolderURL.filePath,
+					)
+				}
 			}
 
-			MAS.printer.notice(action.performed.capitalizingFirstCharacter, snapshot.appNameAndVersion)
 			resumeOnce { $0.resume() }
 		} catch {
 			resumeOnce { $0.resume(throwing: error) }
@@ -281,7 +328,7 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 		let hardLinkURL = try fileManager.url(
 			for: .itemReplacementDirectory,
 			in: .userDomainMask,
-			appropriateFor: URL.homeDirectory,
+			appropriateFor: url,
 			create: true,
 		)
 		.appending(path: "\(adamID)-\(url.lastPathComponent)", directoryHint: .notDirectory)
@@ -289,8 +336,8 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 		return hardLinkURL
 	}
 
-	private func install(appNameAndVersion: String) async throws {
-		guard let pkgHardLinkPath = pkgHardLinkURL?.path(percentEncoded: false) else {
+	private func install(appNameAndVersion: String) async throws -> URL {
+		guard let pkgHardLinkPath = pkgHardLinkURL?.filePath else {
 			throw MASError.error("Failed to find pkg to \(action) \(appNameAndVersion)")
 		}
 		guard let receiptHardLinkURL else {
@@ -309,8 +356,8 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 
 		guard
 			let appFolderURLSubstring = standardErrorString
-			.matches(of: unsafe appFolderURLRegex) // swiftformat:disable:next preferKeyPath
-			.compactMap({ $0.1 }) // swiftlint:disable:this prefer_key_path
+			.matches(of: unsafe appFolderURLRegex)
+			.compactMap(\.1)
 			.min(by: { $0.count < $1.count })
 		else {
 			throw MASError.error(
@@ -318,7 +365,7 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 				error: standardErrorString,
 			)
 		}
-		guard let appFolderURL = URL(string: String(appFolderURLSubstring)) else {
+		guard let appFolderURL = URL(string: .init(appFolderURLSubstring)) else {
 			throw MASError.error(
 				"Failed to parse app folder URL for \(appNameAndVersion) from \(appFolderURLSubstring)",
 				error: standardErrorString,
@@ -329,22 +376,26 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 		do {
 			let fileManager = FileManager.default
 			try run(asEffectiveUID: 0, andEffectiveGID: 0) {
-				if fileManager.fileExists(atPath: receiptURL.path(percentEncoded: false)) {
+				if fileManager.fileExists(atPath: receiptURL.filePath) {
 					try fileManager.removeItem(at: receiptURL)
 				} else {
-					try fileManager.createDirectory(at: receiptURL.deletingLastPathComponent(), withIntermediateDirectories: true)
+					try fileManager.createDirectory(
+						at: receiptURL.deletingLastPathComponent(),
+						withIntermediateDirectories: true,
+						attributes: [.ownerAccountID: 0, .groupOwnerAccountID: 0, .posixPermissions: 0o755],
+					)
 				}
 				try fileManager.copyItem(at: receiptHardLinkURL, to: receiptURL)
 				try fileManager.setAttributes(
-					[.ownerAccountID: 0, .groupOwnerAccountID: 0],
-					ofItemAtPath: receiptURL.path(percentEncoded: false),
+					[.ownerAccountID: 0, .groupOwnerAccountID: 0, .posixPermissions: 0o755],
+					ofItemAtPath: receiptURL.filePath,
 				)
 			}
 		} catch {
 			throw MASError.error(
 				"""
-				Failed to copy receipt for \(appNameAndVersion) from \(receiptHardLinkURL.path(percentEncoded: false).quoted)\
-				 to \(receiptURL.path(percentEncoded: false).quoted)
+				Failed to copy receipt for \(appNameAndVersion) from \(receiptHardLinkURL.filePath.quoted) to\
+				 \(receiptURL.filePath.quoted)
 				""",
 				error: error,
 			)
@@ -352,20 +403,24 @@ private actor DownloadQueueObserver: CKDownloadQueueObserver {
 
 		_ = try await run(
 			"/usr/bin/mdimport",
-			appFolderURL.path(percentEncoded: false),
+			appFolderURL.filePath,
 			errorMessage: "Failed to \(action) \(appNameAndVersion) from \(pkgHardLinkPath)",
 		)
 
 		LSRegisterURL(appFolderURL as NSURL, true) // swiftlint:disable:this legacy_objc_type
+
+		return appFolderURL
 	}
 }
 
 private struct DownloadSnapshot: Sendable { // swiftlint:disable:this one_declaration_per_file
 	let adamID: ADAMID
 	let version: String?
+	let name: String?
 	let appNameAndVersion: String
 	let activePhaseType: PhaseType
 	let phasePercentComplete: Float
+	let appFolderPath: String?
 	let isCancelled: Bool
 	let isFailed: Bool
 	let error: (any Error)?
@@ -376,10 +431,12 @@ private struct DownloadSnapshot: Sendable { // swiftlint:disable:this one_declar
 		}
 
 		adamID = metadata.itemIdentifier
+		name = metadata.title
 		version = metadata.bundleVersion
 		appNameAndVersion = "\(metadata.title ?? "unknown app") (\(version ?? "unknown version"))"
 		activePhaseType = PhaseType(action, rawValue: status.activePhase?.phaseType)
 		phasePercentComplete = status.phasePercentComplete
+		appFolderPath = download.installPath
 		isCancelled = status.isCancelled
 		isFailed = status.isFailed
 		error = status.error.map { $0 as NSError }.map { error in
@@ -453,10 +510,10 @@ private extension URL {
 			return false
 		}
 		guard let fileID1 = try resourceValues(forKeys: [.fileResourceIdentifierKey]).fileResourceIdentifier else {
-			throw MASError.error("Failed to get file resource identifier for \(path(percentEncoded: false))")
+			throw MASError.error("Failed to get file resource identifier for \(filePath)")
 		}
 		guard let fileID2 = try url.resourceValues(forKeys: [.fileResourceIdentifierKey]).fileResourceIdentifier else {
-			throw MASError.error("Failed to get file resource identifier for \(url.path(percentEncoded: false))")
+			throw MASError.error("Failed to get file resource identifier for \(url.filePath)")
 		}
 
 		return fileID1.isEqual(fileID2)
@@ -468,12 +525,7 @@ private func deleteTempFolder(containing url: URL?, fileType: String) {
 		do {
 			try FileManager.default.removeItem(at: url.deletingLastPathComponent())
 		} catch {
-			MAS.printer.warning(
-				"Failed to delete temp folder containing",
-				fileType,
-				url.path(percentEncoded: false),
-				error: error,
-			)
+			MAS.printer.warning("Failed to delete temp folder containing", fileType, url.filePath, error: error)
 		}
 	}
 }
