@@ -2,7 +2,7 @@
 // Get.swift
 // mas
 //
-// Copyright © 2025 mas-cli. All rights reserved.
+// Copyright © 2026 mas-cli. All rights reserved.
 //
 
 internal import ArgumentParser
@@ -19,11 +19,11 @@ extension MAS {
 		@OptionGroup
 		private var forceOptionGroup: ForceOptionGroup
 		@OptionGroup
-		private var requiredAppIDsOptionGroup: RequiredAppIDsOptionGroup
+		private var catalogAppIDsOptionGroup: CatalogAppIDsOptionGroup
 
 		func run() async throws {
 			try await AppStore.get.apps(
-				withAppIDs: requiredAppIDsOptionGroup.appIDs,
+				withAppIDs: catalogAppIDsOptionGroup.appIDs,
 				force: forceOptionGroup.force,
 				installedApps: try await installedApps,
 				lookupAppFromAppID: lookup(appID:),
