@@ -20,16 +20,14 @@ extension MAS {
 		)
 
 		@OptionGroup
-		private var requiredAppIDsOptionGroup: RequiredAppIDsOptionGroup
+		private var catalogAppIDsOptionGroup: CatalogAppIDsOptionGroup
 
 		func run() async {
 			await run(lookupAppFromAppID: lookup(appID:))
 		}
 
-		private func run(lookupAppFromAppID: (AppID) async throws -> CatalogApp) async {
-			await run(
-				catalogApps: await requiredAppIDsOptionGroup.appIDs.lookupCatalogApps(lookupAppFromAppID: lookupAppFromAppID),
-			)
+		private func run(lookupAppFromAppID: @escaping @Sendable (AppID) async throws -> CatalogApp) async {
+			await run(catalogApps: await catalogAppIDsOptionGroup.appIDs.lookupCatalogApps(using: lookupAppFromAppID))
 		}
 
 		func run(catalogApps: [CatalogApp]) async { // swiftformat:disable:this organizeDeclarations
