@@ -6,7 +6,7 @@
 //
 
 internal import ArgumentParser
-private import Foundation
+internal import Foundation
 
 @main
 struct MAS: AsyncParsableCommand, Sendable {
@@ -36,7 +36,7 @@ struct MAS: AsyncParsableCommand, Sendable {
 	static let printer = Printer()
 
 	static var _errorPrefix: String { // swiftlint:disable:this identifier_name
-		"\(format(prefix: "\(errorPrefix)", format: errorFormat, for: FileHandle.standardError)) "
+		"\(errorPrefix.formatted(with: errorFormat, for: FileHandle.standardError)) "
 	}
 
 	private static func main() async { // swiftlint:disable:this unused_declaration
@@ -54,7 +54,7 @@ struct MAS: AsyncParsableCommand, Sendable {
 
 			let errorCount = printer.errorCount
 			if errorCount > 0 {
-				throw ExitCode(errorCount >= UInt64(Int32.max) ? Int32.max : Int32(errorCount))
+				throw ExitCode(errorCount >= UInt64(Int32.max) ? .max : .init(errorCount))
 			}
 		} catch {
 			exit(withError: error)
@@ -120,3 +120,12 @@ extension ParsableCommand {
 private func cast<T>(_ instance: Any, as _: T.Type) -> T? {
 	instance as? T
 }
+
+private let applicationsFolderPath = "/Applications"
+private let applicationsFolderURL = URL(filePath: applicationsFolderPath, directoryHint: .isDirectory)
+
+let applicationsFolderURLs = UserDefaults(suiteName: "com.apple.appstored")?
+.dictionary(forKey: "PreferredVolume")?["name"] // swiftformat:disable indent
+.map { [applicationsFolderURL, URL(filePath: "/Volumes/\($0)\(applicationsFolderPath)", directoryHint: .isDirectory)] }
+?? [applicationsFolderURL]
+// swiftformat:enable indent
