@@ -17,24 +17,26 @@ extension MAS {
 		)
 
 		@OptionGroup
-		private var accurateOptionGroup: AccurateOptionGroup
+		private var accuracyOptionGroup: AccuracyOptionGroup
 		@OptionGroup
 		private var verboseOptionGroup: VerboseOptionGroup
 		@OptionGroup
-		private var optionalAppIDsOptionGroup: OptionalAppIDsOptionGroup
+		private var installedAppIDsOptionGroup: InstalledAppIDsOptionGroup
 
 		func run() async throws {
 			await run(installedApps: try await installedApps.filter(!\.isTestFlight), lookupAppFromAppID: lookup(appID:))
 		}
 
-		private func run(installedApps: [InstalledApp], lookupAppFromAppID: (AppID) async throws -> CatalogApp) async {
+		private func run(
+			installedApps: [InstalledApp],
+			lookupAppFromAppID: @escaping @Sendable (AppID) async throws -> CatalogApp,
+		) async {
 			run(
-				outdatedApps: await outdatedApps(
-					installedApps: installedApps,
+				outdatedApps: await installedApps.outdatedApps(
+					filterFor: installedAppIDsOptionGroup.appIDs,
 					lookupAppFromAppID: lookupAppFromAppID,
-					accurateOptionGroup: accurateOptionGroup,
-					verboseOptionGroup: verboseOptionGroup,
-					optionalAppIDsOptionGroup: optionalAppIDsOptionGroup,
+					accuracy: accuracyOptionGroup.accuracy,
+					shouldWarnIfUnknownApp: verboseOptionGroup.verbose,
 				),
 			)
 		}
