@@ -58,14 +58,13 @@ extension MAS {
 				return
 			}
 
-			// swiftformat:disable:next spaceAroundBrackets
 			var kinfoProcs = unsafe [kinfo_proc](repeating: kinfo_proc(), count: length / MemoryLayout<kinfo_proc>.stride)
 			guard unsafe sysctl(&processListMIB, u_int(processListMIB.count), &kinfoProcs, &length, nil, 0) == 0 else {
 				printer.error("Failed to get process list")
 				return
 			}
 
-			var executablePathBuffer = [CChar](repeating: 0, count: Int(PATH_MAX))
+			var executablePathBuffer = [CChar](repeating: 0, count: .init(PATH_MAX))
 			for pid in unsafe kinfoProcs.map(\.kp_proc.p_pid) {
 				guard
 					unsafe proc_pidpath(pid, &executablePathBuffer, UInt32(executablePathBuffer.count)) > 0,
