@@ -18,40 +18,52 @@ extension MAS {
 		)
 
 		/// Flag indicating that uninstall shouldn't be performed.
-		@Flag(help: "Perform dry run")
-		private var dryRun = false
+		@Flag(name: .customLong("dry-run"), help: "Perform dry run")
+		private var isPerformingDryRun = false
+		@Flag(name: .customLong("all"), help: "Uninstall all App Store apps")
+		private var isUninstallingAll = false
 		@OptionGroup
-		private var requiredAppIDsOptionGroup: RequiredAppIDsOptionGroup
+		private var installedAppIDsOptionGroup: InstalledAppIDsOptionGroup
+
+		func validate() throws {
+			if isUninstallingAll != installedAppIDsOptionGroup.appIDs.isEmpty {
+				throw ValidationError(
+					isUninstallingAll
+					? "Cannot specify both --all & app IDs" // swiftformat:disable:this indent
+					: "Must specify either --all or at least one app ID",
+				)
+			}
+		}
 
 		func run() async throws {
 			try run(installedApps: try await installedApps)
 		}
 
 		private func run(installedApps: [InstalledApp]) throws {
-			let uninstallingAppByPath = requiredAppIDsOptionGroup.appIDs // swiftformat:disable indent
-			.reduce(into: OrderedDictionary<String, InstalledApp>()) { uninstallingAppByPath, appID in
+			let uninstallingAppPathSet = (
+				isUninstallingAll ? installedApps.map { .bundleID($0.bundleID) } : installedAppIDsOptionGroup.appIDs,
+			)
+			.reduce(into: OrderedSet<String>()) { uninstallingAppPathSet, appID in
 				let uninstallingApps = installedApps.filter { $0.matches(appID) }
 				guard !uninstallingApps.isEmpty else {
 					printer.error(appID.notInstalledMessage)
 					return
 				}
 
-				for uninstallingApp in uninstallingApps {
-					uninstallingAppByPath[uninstallingApp.path] = uninstallingApp
-				}
+				uninstallingAppPathSet.append(contentsOf: uninstallingApps.map(\.path))
 			}
-			guard !uninstallingAppByPath.isEmpty else { // swiftformat:enable indent
+			guard !uninstallingAppPathSet.isEmpty else {
 				return
 			}
-			guard !dryRun else {
+			guard !isPerformingDryRun else {
 				printer.notice("Dry run. A wet run would uninstall:\n")
-				for appPath in uninstallingAppByPath.keys {
-					printer.info(appPath)
+				for uninstallingAppPath in uninstallingAppPathSet {
+					printer.info(uninstallingAppPath)
 				}
 				return
 			}
 			guard getuid() == 0 else {
-				try sudo(MAS._commandName, args: [Self._commandName] + uninstallingAppByPath.values.map { String($0.adamID) })
+				try sudo(MAS._commandName, args: CommandLine.arguments.dropFirst())
 				return
 			}
 
@@ -59,7 +71,7 @@ extension MAS {
 			let uid = try processInfo.sudoUID
 			let gid = try processInfo.sudoGID
 			let fileManager = FileManager.default
-			for appPath in uninstallingAppByPath.keys {
+			for appPath in uninstallingAppPathSet {
 				let attributes = try fileManager.attributesOfItem(atPath: appPath)
 				guard let appUID = attributes[.ownerAccountID] as? uid_t else {
 					printer.error("Failed to get uid of", appPath)
@@ -103,7 +115,7 @@ extension MAS {
 
 				var uninstalledAppNSURL = NSURL?.none // swiftlint:disable:this legacy_objc_type
 				try unsafe fileManager.trashItem(
-					at: URL(filePath: appPath, directoryHint: .isDirectory),
+					at: .init(filePath: appPath, directoryHint: .isDirectory),
 					resultingItemURL: &uninstalledAppNSURL,
 				)
 				guard let uninstalledAppPath = uninstalledAppNSURL?.path else {
