@@ -76,89 +76,44 @@ private extension InstalledApp {
 			: false
 		}
 		?? ( // swiftformat:disable indent
-			UniversalSemVer(from: version).compareSemVerAndBuild(to: UniversalSemVer(from: catalogApp.version))
+			UniversalSemVer(from: version).compareSemVerAndBuild(to: .init(from: catalogApp.version))
 			== .orderedAscending
 		)
 	} // swiftformat:enable indent
 }
 
-private extension [InstalledApp] {
-	func filterOutApps(
-		unknownTo lookupAppFromAppID: (AppID) async throws -> CatalogApp,
-		if shouldFilter: Bool,
+extension [InstalledApp] {
+	func outdatedApps(
+		filterFor appIDs: [AppID],
+		lookupAppFromAppID: @escaping @Sendable (AppID) async throws -> CatalogApp,
+		accuracy: OutdatedAccuracy,
 		shouldWarnIfUnknownApp: Bool,
-	) async -> Self {
-		!shouldFilter
-		? self // swiftformat:disable:this indent
-		: await compactMap { installedApp in
-			do {
-				_ = try await lookupAppFromAppID(.adamID(installedApp.adamID))
-				return installedApp
-			} catch {
-				error.print(forExpectedAppName: installedApp.name, shouldWarnIfUnknownApp: shouldWarnIfUnknownApp)
+	) async -> [OutdatedApp] {
+		switch accuracy {
+		case .accurate:
+			await filter(for: appIDs).concurrentCompactMap { await $0.outdated }
+		case .accurateIgnoreUnknownApps:
+			await filter(for: appIDs).concurrentCompactMap { installedApp in
+				do {
+					_ = try await lookupAppFromAppID(.bundleID(installedApp.bundleID))
+					return await installedApp.outdated
+				} catch {
+					error.print(forExpectedAppName: installedApp.name, shouldWarnIfUnknownApp: shouldWarnIfUnknownApp)
+					return nil
+				}
+			}
+		case .inaccurate:
+			await filter(for: appIDs).concurrentCompactMap { installedApp in
+				do {
+					let catalogApp = try await lookupAppFromAppID(.bundleID(installedApp.bundleID))
+					if installedApp.isOutdated(comparedTo: catalogApp) {
+						return OutdatedApp(installedApp, catalogApp.version)
+					}
+				} catch {
+					error.print(forExpectedAppName: installedApp.name, shouldWarnIfUnknownApp: shouldWarnIfUnknownApp)
+				}
 				return nil
 			}
 		}
 	}
 }
-
-func outdatedApps(
-	installedApps: [InstalledApp],
-	lookupAppFromAppID: (AppID) async throws -> CatalogApp,
-	accurateOptionGroup: AccurateOptionGroup,
-	verboseOptionGroup: VerboseOptionGroup,
-	optionalAppIDsOptionGroup: OptionalAppIDsOptionGroup,
-) async -> [OutdatedApp] {
-	await accurateOptionGroup.outdatedApps(
-		accurate: { shouldIgnoreUnknownApps in
-			await withTaskGroup { group in
-				let installedApps = await installedApps
-				.filter(for: optionalAppIDsOptionGroup.appIDs) // swiftformat:disable indent
-				.filterOutApps(
-					unknownTo: lookupAppFromAppID,
-					if: shouldIgnoreUnknownApps,
-					shouldWarnIfUnknownApp: verboseOptionGroup.verbose,
-				)
-				let maxConcurrentTaskCount = min(installedApps.count, 16) // swiftformat:enable indent
-				var index = 0
-				while index < maxConcurrentTaskCount {
-					let installedApp = installedApps[index]
-					index += 1
-					group.addTask {
-						await installedApp.outdated
-					}
-				}
-
-				return await group.reduce(into: [OutdatedApp]()) { outdatedApps, outdatedApp in
-					if let outdatedApp {
-						outdatedApps.append(outdatedApp)
-					}
-
-					guard index < installedApps.count else {
-						return
-					}
-
-					let installedApp = installedApps[index]
-					index += 1
-					_ = group.addTaskUnlessCancelled { await installedApp.outdated }
-				}
-			}
-			.sorted(using: KeyPathComparator(\.installedApp.name, comparator: .localizedStandard))
-		},
-		inaccurate: {
-			await installedApps
-			.filter(for: optionalAppIDsOptionGroup.appIDs) // swiftformat:disable indent
-			.compactMap { installedApp in
-				do {
-					let catalogApp = try await lookupAppFromAppID(.adamID(installedApp.adamID))
-					if installedApp.isOutdated(comparedTo: catalogApp) {
-						return OutdatedApp(installedApp, catalogApp.version)
-					}
-				} catch {
-					error.print(forExpectedAppName: installedApp.name, shouldWarnIfUnknownApp: verboseOptionGroup.verbose)
-				}
-				return nil
-			}
-		}, // swiftformat:enable indent
-	)
-}
