@@ -23,6 +23,7 @@ struct Printer: Sendable {
 	}
 
 	/// Prints to `stdout`.
+	@_disfavoredOverload
 	func info(_ items: Any..., separator: String = " ", terminator: String = "\n") {
 		info(items, separator: separator, terminator: terminator)
 	}
@@ -34,6 +35,7 @@ struct Printer: Sendable {
 
 	/// Prints to `stdout`, prefixed with "==> "; if connected to a terminal, the
 	/// prefix is blue.
+	@_disfavoredOverload
 	func notice(_ items: Any..., separator: String = " ", terminator: String = "\n") {
 		notice(items, separator: separator, terminator: terminator)
 	}
@@ -46,6 +48,7 @@ struct Printer: Sendable {
 
 	/// Prints to `stderr`, prefixed with "Warning: "; if connected to a terminal,
 	/// the prefix is yellow & underlined.
+	@_disfavoredOverload
 	func warning(_ items: Any..., error: (any Error)? = nil, separator: String = " ", terminator: String = "\n") {
 		warning(items, error: error, separator: separator, terminator: terminator)
 	}
@@ -58,6 +61,7 @@ struct Printer: Sendable {
 
 	/// Prints to `stderr`, prefixed with "Error: "; if connected to a terminal,
 	/// the prefix is red & underlined.
+	@_disfavoredOverload
 	func error(_ items: Any..., error: (any Error)? = nil, separator: String = " ", terminator: String = "\n") {
 		self.error(items, error: error, separator: separator, terminator: terminator)
 	}
@@ -120,20 +124,40 @@ struct Printer: Sendable {
 		separator: String,
 		terminator: String,
 		to fileHandle: FileHandle,
-	) {
-		let formattedPrefix = mas.format(prefix: prefix, format: format, for: fileHandle)
+	) { // swiftformat:disable indent
+		let indent = """
+
+			\(
+				String( // swiftlint:disable:this indentation_width
+					repeating: " ",
+					count:
+						(prefix.range(of: "\n", options: .backwards).map { .init(prefix[$0.upperBound...]) } ?? prefix).count + 1,
+				)
+			)
+			"""
+
+		let formattedPrefix = prefix.formatted(with: format, for: fileHandle) // swiftformat:enable indent
 		print(
-			items.first.map { ["\(formattedPrefix) \($0)"] + items.dropFirst().map(String.init(describing:)) }
+			items.first.map { item in
+				["\(formattedPrefix) \(mas.indent(item, with: indent))"]
+				+ items.dropFirst().map { mas.indent($0, with: indent) } // swiftformat:disable:this indent
+			}
 			?? [formattedPrefix], // swiftformat:disable:this indent
-			separator: separator,
+			separator: mas.indent(separator, with: indent),
 			terminator: terminator,
 			to: fileHandle,
 		)
 	}
 }
 
-func format(prefix: String, format: String, for fileHandle: FileHandle) -> String {
-	fileHandle.isTerminal ? "\(csi)\(format)m\(prefix)\(csi)0m" : prefix
+extension String {
+	func formatted(with format: Self, for fileHandle: FileHandle) -> Self {
+		fileHandle.isTerminal ? "\(csi)\(format)m\(self)\(csi)0m" : self
+	}
+}
+
+private func indent(_ item: Any, with indent: String) -> String {
+	.init(describing: item).replacing(unsafe nonEmptyLineStartRegex, with: indent)
 }
 
 let errorPrefix = "Error:"
@@ -141,3 +165,5 @@ let errorFormat = "4;31"
 
 /// Terminal Control Sequence Indicator.
 private let csi = "\u{001B}["
+
+private nonisolated(unsafe) let nonEmptyLineStartRegex = /\n(?!\n)/
