@@ -10,7 +10,7 @@ private import Darwin
 private import Foundation
 
 func sudo(_ executableName: String, args: some Sequence<String>) throws {
-	guard let executablePath = Bundle.main.executableURL?.path(percentEncoded: false) else {
+	guard let executablePath = Bundle.main.executableURL?.filePath else {
 		throw MASError.error("Failed to get the executable path for sudo \(executableName) \(args.joined(separator: " "))")
 	}
 
@@ -18,7 +18,7 @@ func sudo(_ executableName: String, args: some Sequence<String>) throws {
 }
 
 private func sudo(_ args: some Sequence<String>) throws {
-	let cArgs = unsafe (["sudo"] + args).map { unsafe strdup($0) } // swiftformat:disable:this spaceAroundParens
+	let cArgs = unsafe (["sudo", "MAS_NO_AUTO_INDEX=1"] + args).map { unsafe strdup($0) }
 	defer {
 		for unsafe cArg in unsafe cArgs {
 			unsafe free(cArg)
