@@ -13,7 +13,7 @@ private extension MASTests {
 	@Test
 	func parsesCatalogAppFromThingsThatGoBumpJSON() {
 		let actual = consequencesOf(
-			try JSONDecoder().decode(CatalogApp.self, from: Data(fromResource: "things-lookup")).adamID,
+			try JSONDecoder().decode(CatalogApp.self, from: .init(fromResource: "things-lookup")).adamID,
 		)
 		let expected = Consequences(1_472_954_003 as ADAMID)
 		#expect(actual == expected)
